package cn.com.infosec.asn1.esf;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.DisplayText;
import cn.com.infosec.asn1.x509.NoticeReference;
import java.util.Enumeration;

public class SPUserNotice {
   private NoticeReference noticeRef;
   private DisplayText explicitText;

   public static SPUserNotice getInstance(Object obj) {
      if (obj != null && !(obj instanceof SPUserNotice)) {
         if (obj instanceof ASN1Sequence) {
            return new SPUserNotice((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in 'SPUserNotice' factory : " + obj.getClass().getName() + ".");
         }
      } else {
         return (SPUserNotice)obj;
      }
   }

   public SPUserNotice(ASN1Sequence seq) {
      Enumeration seq1 = seq.getObjects();

      while(seq1.hasMoreElements()) {
         DEREncodable var2;
         if ((var2 = (DEREncodable)seq1.nextElement()) instanceof NoticeReference) {
            this.noticeRef = NoticeReference.getInstance(var2);
         } else {
            if (!(var2 instanceof DisplayText)) {
               throw new IllegalArgumentException("Invalid element in 'SPUserNotice'.");
            }

            this.explicitText = DisplayText.getInstance(var2);
         }
      }

   }

   public SPUserNotice(NoticeReference noticeRef, DisplayText explicitText) {
      this.noticeRef = noticeRef;
      this.explicitText = explicitText;
   }

   public NoticeReference getNoticeRef() {
      return this.noticeRef;
   }

   public DisplayText getExplicitText() {
      return this.explicitText;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      NoticeReference var2;
      if ((var2 = this.noticeRef) != null) {
         var1.add(var2);
      }

      DisplayText var3;
      if ((var3 = this.explicitText) != null) {
         var1.add(var3);
      }

      return new DERSequence(var1);
   }
}
